@@ -10,10 +10,10 @@ from dataclasses import dataclass, field
 from datetime import datetime
 from functools import wraps
 from getpass import getpass
+from inspect import isclass
 from itertools import islice
 from time import monotonic
 from types import FrameType, TracebackType
-from inspect import isclass
 from typing import (
     IO,
     TYPE_CHECKING,
@@ -28,12 +28,10 @@ from typing import (
     TextIO,
     Tuple,
     Type,
-    Tuple,
     Union,
     cast,
 )
 
-
 if sys.version_info >= (3, 8):
     from typing import Literal, Protocol, runtime_checkable
 else:
@@ -43,13 +41,13 @@ else:
         runtime_checkable,
     )  # pragma: no cover
 
-
 from . import errors, themes
 from ._emoji_replace import _emoji_replace
 from ._log_render import FormatTimeCallable, LogRender
 from .align import Align, AlignMethod
 from .color import ColorSystem
 from .control import Control
+from .emoji import EmojiVariant
 from .highlighter import NullHighlighter, ReprHighlighter
 from .markup import render as render_markup
 from .measure import Measurement, measure_renderables
@@ -74,7 +72,6 @@ WINDOWS = platform.system() == "Windows"
 
 HighlighterType = Callable[[Union[str, "Text"]], "Text"]
 JustifyMethod = Literal["default", "left", "center", "right", "full"]
-
 OverflowMethod = Literal["fold", "crop", "ellipsis", "ignore"]
 
 
@@ -134,6 +131,8 @@ class ConsoleOptions:
     """True if the target is a terminal, otherwise False."""
     encoding: str
     """Encoding of terminal."""
+    max_height: int
+    """Height of container (starts as terminal)"""
     justify: Optional[JustifyMethod] = None
     """Justify value override for renderable."""
     overflow: Optional[OverflowMethod] = None
@@ -145,7 +144,6 @@ class ConsoleOptions:
     markup: Optional[bool] = None
     """Enable markup when rendering strings."""
     height: Optional[int] = None
-    """Height available, or None for no height limit."""
 
     @property
     def ascii_only(self) -> bool:
@@ -194,6 +192,8 @@ class ConsoleOptions:
         if not isinstance(markup, NoChange):
             options.markup = markup
         if not isinstance(height, NoChange):
+            if height is not None:
+                options.max_height = height
             options.height = None if height is None else max(0, height)
         return options
 
@@ -223,6 +223,7 @@ class ConsoleOptions:
         options = self.copy()
         options.min_width = options.max_width = max(0, width)
         options.height = height
+        options.max_height = height
         return options
 
 
@@ -404,7 +405,7 @@ class ScreenContext:
         """
         if renderables:
             self.screen.renderable = (
-                RenderGroup(*renderables) if len(renderables) > 1 else renderables[0]
+                Group(*renderables) if len(renderables) > 1 else renderables[0]
             )
         if style is not None:
             self.screen.style = style
@@ -428,7 +429,7 @@ class ScreenContext:
                 self.console.show_cursor(True)
 
 
-class RenderGroup:
+class Group:
     """Takes a group of renderables and returns a renderable object that renders the group.
 
     Args:
@@ -461,7 +462,10 @@ class RenderGroup:
         yield from self.renderables
 
 
-def render_group(fit: bool = True) -> Callable[..., Callable[..., RenderGroup]]:
+RenderGroup = Group  # TODO: deprecate at some point
+
+
+def group(fit: bool = True) -> Callable[..., Callable[..., Group]]:
     """A decorator that turns an iterable of renderables in to a group.
 
     Args:
@@ -470,19 +474,22 @@ def render_group(fit: bool = True) -> Callable[..., Callable[..., RenderGroup]]:
 
     def decorator(
         method: Callable[..., Iterable[RenderableType]]
-    ) -> Callable[..., RenderGroup]:
+    ) -> Callable[..., Group]:
         """Convert a method that returns an iterable of renderables in to a RenderGroup."""
 
         @wraps(method)
-        def _replace(*args: Any, **kwargs: Any) -> RenderGroup:
+        def _replace(*args: Any, **kwargs: Any) -> Group:
             renderables = method(*args, **kwargs)
-            return RenderGroup(*renderables, fit=fit)
+            return Group(*renderables, fit=fit)
 
         return _replace
 
     return decorator
 
 
+render_group = group
+
+
 def _is_jupyter() -> bool:  # pragma: no cover
     """Check if we're running in a Jupyter notebook."""
     try:
@@ -585,6 +592,7 @@ class Console:
             required to call :meth:`export_html` and :meth:`export_text`. Defaults to False.
         markup (bool, optional): Boolean to enable :ref:`console_markup`. Defaults to True.
         emoji (bool, optional): Enable emoji code. Defaults to True.
+        emoji_variant (str, optional): Optional emoji variant, either "text" or "emoji". Defaults to None.
         highlight (bool, optional): Enable automatic highlighting. Defaults to True.
         log_time (bool, optional): Boolean to enable logging of time by :meth:`log` methods. Defaults to True.
         log_path (bool, optional): Boolean to enable the logging of the caller by :meth:`log`. Defaults to True.
@@ -621,6 +629,7 @@ class Console:
         record: bool = False,
         markup: bool = True,
         emoji: bool = True,
+        emoji_variant: Optional[EmojiVariant] = None,
         highlight: bool = True,
         log_time: bool = True,
         log_path: bool = True,
@@ -657,6 +666,7 @@ class Console:
         self.record = record
         self._markup = markup
         self._emoji = emoji
+        self._emoji_variant = emoji_variant
         self._highlight = highlight
         self.legacy_windows: bool = (
             (detect_legacy_windows() and not self.is_jupyter)
@@ -907,6 +917,7 @@ class Console:
     def options(self) -> ConsoleOptions:
         """Get default console options."""
         return ConsoleOptions(
+            max_height=self.size.height,
             size=self.size,
             legacy_windows=self.legacy_windows,
             min_width=1,
@@ -934,15 +945,11 @@ class Console:
         if WINDOWS:  # pragma: no cover
             width, height = shutil.get_terminal_size()
         else:
-
             try:
-                width, height = os.get_terminal_size(sys.stdin.fileno())
-
+                width, height = os.get_terminal_size(sys.__stdin__.fileno())
             except (AttributeError, ValueError, OSError):
                 try:
-
-                    width, height = os.get_terminal_size(sys.stdout.fileno())
-
+                    width, height = os.get_terminal_size(sys.__stdout__.fileno())
                 except (AttributeError, ValueError, OSError):
                     pass
 
@@ -1079,7 +1086,6 @@ class Console:
 
         Args:
             status (RenderableType): A status renderable (str or Text typically).
-            console (Console, optional): Console instance to use, or None for global console. Defaults to None.
             spinner (str, optional): Name of spinner animation (see python -m rich.spinner). Defaults to "dots".
             spinner_style (StyleType, optional): Style of spinner. Defaults to "status.spinner".
             speed (float, optional): Speed factor for spinner animation. Defaults to 1.0.
@@ -1308,12 +1314,19 @@ class Console:
         highlight_enabled = highlight or (highlight is None and self._highlight)
 
         if markup_enabled:
-            rich_text = render_markup(text, style=style, emoji=emoji_enabled)
+            rich_text = render_markup(
+                text,
+                style=style,
+                emoji=emoji_enabled,
+                emoji_variant=self._emoji_variant,
+            )
             rich_text.justify = justify
             rich_text.overflow = overflow
         else:
             rich_text = Text(
-                _emoji_replace(text) if emoji_enabled else text,
+                _emoji_replace(text, default_variant=self._emoji_variant)
+                if emoji_enabled
+                else text,
                 justify=justify,
                 overflow=overflow,
                 style=style,
@@ -1570,6 +1583,7 @@ class Console:
                 height=height,
                 no_wrap=no_wrap,
                 markup=markup,
+                highlight=highlight,
             )
 
             new_segments: List[Segment] = []
@@ -1600,6 +1614,34 @@ class Console:
             else:
                 self._buffer.extend(new_segments)
 
+    def print_json(
+        self,
+        json: Optional[str] = None,
+        *,
+        data: Any = None,
+        indent: int = 2,
+        highlight: bool = True,
+    ) -> None:
+        """Pretty prints JSON. Output will be valid JSON.
+
+        Args:
+            json (Optional[str]): A string containing JSON.
+            data (Any): If json is not supplied, then encode this data.
+            indent (int, optional): Number of spaces to indent. Defaults to 2.
+            highlight (bool, optional): Enable highlighting of output: Defaults to True.
+        """
+        from rich.json import JSON
+
+        if json is None:
+            json_renderable = JSON.from_data(data, indent=indent, highlight=highlight)
+        else:
+            if not isinstance(json, str):
+                raise TypeError(
+                    f"json must be str. Did you mean print_json(data={json!r}) ?"
+                )
+            json_renderable = JSON(json, indent=indent, highlight=highlight)
+        self.print(json_renderable)
+
     def update_screen(
         self,
         renderable: RenderableType,
